==> oci-2.2.1-py2.py3-none-any.whl: oci/ons/models/subscription_summary.py <==
# coding: utf-8
# Copyright (c) 2016, 2019, Oracle and/or its affiliates. All rights reserved.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SubscriptionSummary(object):
    """
    The subscription's configuration summary.
    """

    #: A constant which can be used with the lifecycle_state property of a SubscriptionSummary.
    #: This constant has a value of "PENDING"
    LIFECYCLE_STATE_PENDING = "PENDING"

    #: A constant which can be used with the lifecycle_state property of a SubscriptionSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a SubscriptionSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    def __init__(self, **kwargs):
        """
        Initializes a new SubscriptionSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this SubscriptionSummary.
        :type id: str

        :param topic_id:
            The value to assign to the topic_id property of this SubscriptionSummary.
        :type topic_id: str

        :param protocol:
            The value to assign to the protocol property of this SubscriptionSummary.
        :type protocol: str

        :param endpoint:
            The value to assign to the endpoint property of this SubscriptionSummary.
        :type endpoint: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this SubscriptionSummary.
            Allowed values for this property are: "PENDING", "ACTIVE", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param created_time:
            The value to assign to the created_time property of this SubscriptionSummary.
        :type created_time: int

        :param delivery_policy:
            The value to assign to the delivery_policy property of this SubscriptionSummary.
        :type delivery_policy: DeliveryPolicy

        :param etag:
            The value to assign to the etag property of this SubscriptionSummary.
        :type etag: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this SubscriptionSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this SubscriptionSummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'topic_id': 'str',
            'protocol': 'str',
            'endpoint': 'str',
            'lifecycle_state': 'str',
            'created_time': 'int',
            'delivery_policy': 'DeliveryPolicy',
            'etag': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'topic_id': 'topicId',
            'protocol': 'protocol',
            'endpoint': 'endpoint',
            'lifecycle_state': 'lifecycleState',
            'created_time': 'createdTime',
            'delivery_policy': 'deliveryPolicy',
            'etag': 'etag',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._topic_id = None
        self._protocol = None
        self._endpoint = None
        self._lifecycle_state = None
        self._created_time = None
        self._delivery_policy = None
        self._etag = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this SubscriptionSummary.
        The `OCID`__ of the subscription.

        __ https://docs.us-phoenix-1.oraclecloud.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this SubscriptionSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SubscriptionSummary.
        The `OCID`__ of the subscription.

        __ https://docs.us-phoenix-1.oraclecloud.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this SubscriptionSummary.
        :type: str
        """
        self._id = id

    @property
    def topic_id(self):
        """
        **[Required]** Gets the topic_id of this SubscriptionSummary.
        The `OCID`__ of the associated topic.

        __ https://docs.us-phoenix-1.oraclecloud.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The topic_id of this SubscriptionSummary.
        :rtype: str
        """
        return self._topic_id

    @topic_id.setter
    def topic_id(self, topic_id):
        """
        Sets the topic_id of this SubscriptionSummary.
        The `OCID`__ of the associated topic.

        __ https://docs.us-phoenix-1.oraclecloud.com/iaas/Content/General/Concepts/identifiers.htm


        :param topic_id: The topic_id of this SubscriptionSummary.
        :type: str
        """
        self._topic_id = topic_id

    @property
    def protocol(self):
        """
        **[Required]** Gets the protocol of this SubscriptionSummary.
        The protocol used for the subscription. Valid values: EMAIL, HTTPS.


        :return: The protocol of this SubscriptionSummary.
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """
        Sets the protocol of this SubscriptionSummary.
        The protocol used for the subscription. Valid values: EMAIL, HTTPS.


        :param protocol: The protocol of this SubscriptionSummary.
        :type: str
        """
        self._protocol = protocol

    @property
    def endpoint(self):
        """
        **[Required]** Gets the endpoint of this SubscriptionSummary.
        The endpoint of the subscription. Valid values depend on the protocol.
        For EMAIL, only an email address is valid. For HTTPS, only a PagerDuty URL is valid. A URL cannot exceed 512 characters.
        Avoid entering confidential information.


        :return: The endpoint of this SubscriptionSummary.
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """
        Sets the endpoint of this SubscriptionSummary.
        The endpoint of the subscription. Valid values depend on the protocol.
        For EMAIL, only an email address is valid. For HTTPS, only a PagerDuty URL is valid. A URL cannot exceed 512 characters.
        Avoid entering confidential information.


        :param endpoint: The endpoint of this SubscriptionSummary.
        :type: str
        """
        self._endpoint = endpoint

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this SubscriptionSummary.
        The lifecycle state of the subscription. Default value for a newly created subscription: PENDING.

        Allowed values for this property are: "PENDING", "ACTIVE", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this SubscriptionSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this SubscriptionSummary.
        The lifecycle state of the subscription. Default value for a newly created subscription: PENDING.


        :param lifecycle_state: The lifecycle_state of this SubscriptionSummary.
        :type: str
        """
        allowed_values = ["PENDING", "ACTIVE", "DELETED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def created_time(self):
        """
        Gets the created_time of this SubscriptionSummary.
        The time when this suscription was created.


        :return: The created_time of this SubscriptionSummary.
        :rtype: int
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """
        Sets the created_time of this SubscriptionSummary.
        The time when this suscription was created.


        :param created_time: The created_time of this SubscriptionSummary.
        :type: int
        """
        self._created_time = created_time

    @property
    def delivery_policy(self):
        """
        Gets the delivery_policy of this SubscriptionSummary.

        :return: The delivery_policy of this SubscriptionSummary.
        :rtype: DeliveryPolicy
        """
        return self._delivery_policy

    @delivery_policy.setter
    def delivery_policy(self, delivery_policy):
        """
        Sets the delivery_policy of this SubscriptionSummary.

        :param delivery_policy: The delivery_policy of this SubscriptionSummary.
        :type: DeliveryPolicy
        """
        self._delivery_policy = delivery_policy

    @property
    def etag(self):
        """
        Gets the etag of this SubscriptionSummary.
        For optimistic concurrency control. See `if-match`.


        :return: The etag of this SubscriptionSummary.
        :rtype: str
        """
        return self._etag

    @etag.setter
    def etag(self, etag):
        """
        Sets the etag of this SubscriptionSummary.
        For optimistic concurrency control. See `if-match`.


        :param etag: The etag of this SubscriptionSummary.
        :type: str
        """
        self._etag = etag

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this SubscriptionSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this SubscriptionSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this SubscriptionSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this SubscriptionSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this SubscriptionSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this SubscriptionSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this SubscriptionSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this SubscriptionSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other

==> oci-2.2.11-py2.py3-none-any.whl: oci/ons/models/subscription_summary.py <==
# coding: utf-8
# Copyright (c) 2016, 2019, Oracle and/or its affiliates. All rights reserved.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SubscriptionSummary(object):
    """
    The subscription's configuration summary.
    """

    #: A constant which can be used with the lifecycle_state property of a SubscriptionSummary.
    #: This constant has a value of "PENDING"
    LIFECYCLE_STATE_PENDING = "PENDING"

    #: A constant which can be used with the lifecycle_state property of a SubscriptionSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a SubscriptionSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    def __init__(self, **kwargs):
        """
        Initializes a new SubscriptionSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this SubscriptionSummary.
        :type id: str

        :param topic_id:
            The value to assign to the topic_id property of this SubscriptionSummary.
        :type topic_id: str

        :param protocol:
            The value to assign to the protocol property of this SubscriptionSummary.
        :type protocol: str

        :param endpoint:
            The value to assign to the endpoint property of this SubscriptionSummary.
        :type endpoint: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this SubscriptionSummary.
            Allowed values for this property are: "PENDING", "ACTIVE", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param created_time:
            The value to assign to the created_time property of this SubscriptionSummary.
        :type created_time: int

        :param delivery_policy:
            The value to assign to the delivery_policy property of this SubscriptionSummary.
        :type delivery_policy: DeliveryPolicy

        :param etag:
            The value to assign to the etag property of this SubscriptionSummary.
        :type etag: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this SubscriptionSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this SubscriptionSummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'topic_id': 'str',
            'protocol': 'str',
            'endpoint': 'str',
            'lifecycle_state': 'str',
            'created_time': 'int',
            'delivery_policy': 'DeliveryPolicy',
            'etag': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'topic_id': 'topicId',
            'protocol': 'protocol',
            'endpoint': 'endpoint',
            'lifecycle_state': 'lifecycleState',
            'created_time': 'createdTime',
            'delivery_policy': 'deliveryPolicy',
            'etag': 'etag',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._topic_id = None
        self._protocol = None
        self._endpoint = None
        self._lifecycle_state = None
        self._created_time = None
        self._delivery_policy = None
        self._etag = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this SubscriptionSummary.
        The `OCID`__ of the subscription.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this SubscriptionSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SubscriptionSummary.
        The `OCID`__ of the subscription.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this SubscriptionSummary.
        :type: str
        """
        self._id = id

    @property
    def topic_id(self):
        """
        **[Required]** Gets the topic_id of this SubscriptionSummary.
        The `OCID`__ of the associated topic.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The topic_id of this SubscriptionSummary.
        :rtype: str
        """
        return self._topic_id

    @topic_id.setter
    def topic_id(self, topic_id):
        """
        Sets the topic_id of this SubscriptionSummary.
        The `OCID`__ of the associated topic.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param topic_id: The topic_id of this SubscriptionSummary.
        :type: str
        """
        self._topic_id = topic_id

    @property
    def protocol(self):
        """
        **[Required]** Gets the protocol of this SubscriptionSummary.
        The protocol used for the subscription. Valid values: EMAIL, HTTPS.


        :return: The protocol of this SubscriptionSummary.
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """
        Sets the protocol of this SubscriptionSummary.
        The protocol used for the subscription. Valid values: EMAIL, HTTPS.


        :param protocol: The protocol of this SubscriptionSummary.
        :type: str
        """
        self._protocol = protocol

    @property
    def endpoint(self):
        """
        **[Required]** Gets the endpoint of this SubscriptionSummary.
        The endpoint of the subscription. Valid values depend on the protocol.
        For EMAIL, only an email address is valid. For HTTPS, only a PagerDuty URL is valid. A URL cannot exceed 512 characters.
        Avoid entering confidential information.


        :return: The endpoint of this SubscriptionSummary.
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """
        Sets the endpoint of this SubscriptionSummary.
        The endpoint of the subscription. Valid values depend on the protocol.
        For EMAIL, only an email address is valid. For HTTPS, only a PagerDuty URL is valid. A URL cannot exceed 512 characters.
        Avoid entering confidential information.


        :param endpoint: The endpoint of this SubscriptionSummary.
        :type: str
        """
        self._endpoint = endpoint

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this SubscriptionSummary.
        The lifecycle state of the subscription. Default value for a newly created subscription: PENDING.

        Allowed values for this property are: "PENDING", "ACTIVE", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this SubscriptionSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this SubscriptionSummary.
        The lifecycle state of the subscription. Default value for a newly created subscription: PENDING.


        :param lifecycle_state: The lifecycle_state of this SubscriptionSummary.
        :type: str
        """
        allowed_values = ["PENDING", "ACTIVE", "DELETED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def created_time(self):
        """
        Gets the created_time of this SubscriptionSummary.
        The time when this suscription was created.


        :return: The created_time of this SubscriptionSummary.
        :rtype: int
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """
        Sets the created_time of this SubscriptionSummary.
        The time when this suscription was created.


        :param created_time: The created_time of this SubscriptionSummary.
        :type: int
        """
        self._created_time = created_time

    @property
    def delivery_policy(self):
        """
        Gets the delivery_policy of this SubscriptionSummary.

        :return: The delivery_policy of this SubscriptionSummary.
        :rtype: DeliveryPolicy
        """
        return self._delivery_policy

    @delivery_policy.setter
    def delivery_policy(self, delivery_policy):
        """
        Sets the delivery_policy of this SubscriptionSummary.

        :param delivery_policy: The delivery_policy of this SubscriptionSummary.
        :type: DeliveryPolicy
        """
        self._delivery_policy = delivery_policy

    @property
    def etag(self):
        """
        Gets the etag of this SubscriptionSummary.
        For optimistic concurrency control. See `if-match`.


        :return: The etag of this SubscriptionSummary.
        :rtype: str
        """
        return self._etag

    @etag.setter
    def etag(self, etag):
        """
        Sets the etag of this SubscriptionSummary.
        For optimistic concurrency control. See `if-match`.


        :param etag: The etag of this SubscriptionSummary.
        :type: str
        """
        self._etag = etag

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this SubscriptionSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this SubscriptionSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this SubscriptionSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this SubscriptionSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this SubscriptionSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this SubscriptionSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this SubscriptionSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this SubscriptionSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
